#ifndef STATUSHILDON_H
#define STATUSHILDON_H

/*
  WifiInfo - Show current Wifi sttaus
  Copyright (C) 2008  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "StatusLinux.h"

#include <dbus/dbus.h>

class StatusHildon : public StatusLinux
{
private:
  DBusConnection* GetDBusConnection();

public:
  StatusHildon();

  bool SupportsNetworkRetrieval() const;
  bool UpdateNetworks();

  bool CanChangePowerSaving() const;
  bool SetPowerSaving(bool savePower);

  bool HandleMessage(DBusConnection *connection, DBusMessage *msg);
};

#endif
